pub(crate) struct TimestampState {
date: Option<Date>,
time: Option<Time>,
date_state: <Date as ComponentProvider>::State,
}Available on crate feature
formatting only.Expand description
State used by Timestamp to cache computed date and time values.
Date and Time are cached separately, with the Date’s state being stored to allow for
reusing existing methods.
Fields
date: Option<Date>time: Option<Time>date_state: <Date as ComponentProvider>::StateTrait Implementations
Sourceimpl Debug for TimestampState
impl Debug for TimestampState
Sourceimpl Default for TimestampState
impl Default for TimestampState
Sourcefn default() -> TimestampState
fn default() -> TimestampState
Returns the “default value” for a type. Read more